Stan Math Library: stan/math/prim/mat/fun/mdivide_right.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_right.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/mat/fun/mdivide_left.hpp>
7 #include <stan/math/prim/mat/fun/transpose.hpp>
8 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
9 #include <stan/math/prim/mat/err/check_square.hpp>
10
11 namespace stan {
12 namespace math {
13
22 template <typename T1, typename T2, int R1, int C1, int R2, int C2>
23 inline
24 Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
25 R1, C2>
26 mdivide_right(const Eigen::Matrix<T1, R1, C1> &b,
27 const Eigen::Matrix<T2, R2, C2> &A) {
28 stan::math::check_square("mdivide_right", "A", A);
29 stan::math::check_multiplicable("mdivide_right",
30 "b", b,
31 "A", A);
32 // FIXME: This is nice and general but likely slow.
33 return transpose(mdivide_left(transpose(A), transpose(b)));
34 // return promote_common<Eigen::Matrix<T1, R2, C2>,
35 // Eigen::Matrix<T2, R2, C2> >(A)
36 // .transpose()
37 // .lu()
38 // .solve(promote_common<Eigen::Matrix<T1, R1, C1>,
39 // Eigen::Matrix<T2, R1, C1> >(b)
40 // .transpose())
41 // .transpose();
42 }
43
44 }
45 }
46 #endif
stan::math::mdivide_left
Eigen::Matrix< fvar< T >, R1, C2 > mdivide_left(const Eigen::Matrix< fvar< T >, R1, C1 > &A, const Eigen::Matrix< fvar< T >, R2, C2 > &b)
Definition: mdivide_left.hpp:24
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
transpose.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
stan::math::mdivide_right
Eigen::Matrix< fvar< T >, R1, C2 > mdivide_right(const Eigen::Matrix< fvar< T >, R1, C1 > &A, const Eigen::Matrix< fvar< T >, R2, C2 > &b)
Definition: mdivide_right.hpp:24
mdivide_left.hpp
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.